@@ -2,16 +2,16 @@
  * File: gkrellxmms2.c
  *
  * GKrellM 2 Plugin to control XMMS2
- * Copyright (c) 2005-2006 Johannes Heimansberg
+ * Copyright (c) 2005-2010 Johannes Heimansberg
  *
  * requires GKrellM 2 and XMMS2
  *
- * Version: 0.7.0
+ * Version: 0.7.1
  *
  * Released under the GNU General Public License v2
  */
 
-#define VERSION_NUMBER "0.7.0"
+#define VERSION_NUMBER "0.7.1"
 
 #if !defined(WIN32)
 #include <gkrellm2/gkrellm.h>
@@ -26,6 +26,7 @@
 #include "gtrackinfo/gtrackinfo.h"
 #include "gmedialib/gmedialib.h"
 #include "buttons.h"
+#include "setupwidget.h"
 #include "playlist.xpm"
 
 #define PLUGIN_NAME "gkrellxmms2"
@@ -45,6 +46,7 @@ static GtkWidget      *gml = NULL;
 xmmsc_connection_t    *connection;
 static trackinfo       track;
 static gboolean        local_xmms2d = FALSE;
+static SetupWidget     sw;
 
 #if defined(GKRELLM_HAVE_DECAL_SCROLL_TEXT)
 static gboolean       scroll_loop_mode;
@@ -176,7 +178,7 @@ static void cb_panel_release_event(GtkWidget *widget, GdkEventButton *event,
 		if (xmms2ctrl_get_error() != ERROR_CONNECTION &&
 		    trackinfo_get_playtime(&track) > seek_ms && event->y < yoffset &&
 		    seek_in_progress) {
-			res = xmmsc_playback_seek_ms(connection, seek_ms);
+			res = xmmsc_playback_seek_ms(connection, seek_ms, XMMS_PLAYBACK_SEEK_SET);
 			xmmsc_result_unref(res);
 		}
 		seek_in_progress = FALSE;
@@ -258,21 +260,13 @@ static gint panel_expose_event(GtkWidget *widget, GdkEventExpose *ev)
 	return FALSE;
 }
 
-static void sig_handle_playtime(xmmsc_result_t *res, void *userdata)
+static int sig_handle_playtime(xmmsv_t *val, void *userdata)
 {
-	xmmsc_result_t *res2;
-	guint          ptime;
+	gint           ptime = 0;
 	static guint   cnt = 0;
 
-	if (xmms2ctrl_get_error() != ERROR_CONNECTION) {
-		if (xmmsc_result_iserror(res))
-			return;
-		if (!xmmsc_result_get_uint(res, &ptime))
-			return;
-
-		res2 = xmmsc_result_restart(res);
-		xmmsc_result_unref(res);
-		xmmsc_result_unref(res2);
+	if (xmms2ctrl_get_error() != ERROR_CONNECTION && !xmmsv_is_error(val)) {
+		xmmsv_get_int(val, &ptime);
 	}
 	if (cnt > 10) {
 		cnt = 0;
@@ -282,6 +276,7 @@ static void sig_handle_playtime(xmmsc_result_t *res, void *userdata)
 			gkrellm_update_krell(panel, krell, ptime / 1000);
 	}
 	cnt++;
+	return TRUE;
 }
 
 static void update_plugin()
@@ -325,22 +320,21 @@ static void update_plugin()
 }
 
 
-static void n_media_lib_get_info(xmmsc_result_t *res, void *arg)
+static int n_media_lib_get_info(xmmsv_t *val, void *arg)
 {
-	trackinfo_update(res, &track);
+	trackinfo_update(val, &track);
 	update_krell();
 	update_plugin();
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
-static guint current_id;
+static gint current_id;
 
-static void bc_handle_medialib_entry_changed(xmmsc_result_t *res, 
-                                             void           *userdata)
+static int bc_handle_medialib_entry_changed(xmmsv_t *val, void *userdata)
 {
-	guint id;
+	gint id;
 
-	if (xmmsc_result_get_uint(res, &id) && 
+	if (xmmsv_get_int(val, &id) && 
 	    xmms2ctrl_get_error() != ERROR_CONNECTION) {
 	    if (current_id == id) {
 			xmmsc_result_t *res2;
@@ -350,11 +344,12 @@ static void bc_handle_medialib_entry_changed(xmmsc_result_t *res,
 			xmmsc_result_unref(res2);
 		}
 	}
+	return TRUE;
 }
 
-static void bc_handle_current_id(xmmsc_result_t *res, void *userdata)
+static int bc_handle_current_id(xmmsv_t *val, void *userdata)
 {
-	if (xmmsc_result_get_uint(res, &current_id) && 
+	if (xmmsv_get_int(val, &current_id) && 
 	    xmms2ctrl_get_error() != ERROR_CONNECTION) {
 	    xmmsc_result_t *res2;
 
@@ -362,11 +357,12 @@ static void bc_handle_current_id(xmmsc_result_t *res, void *userdata)
 	    xmmsc_result_notifier_set(res2, n_media_lib_get_info, &current_id);
 	    xmmsc_result_unref(res2);
 	}
+	return TRUE;
 }
 
-static void sig_handle_current_id(xmmsc_result_t *res, void *userdata)
+static int sig_handle_current_id(xmmsv_t *val, void *userdata)
 {
-	if (xmmsc_result_get_uint(res, &current_id) && 
+	if (xmmsv_get_int(val, &current_id) && 
 	    xmms2ctrl_get_error() != ERROR_CONNECTION) {
 	    xmmsc_result_t *res2;
 
@@ -374,17 +370,17 @@ static void sig_handle_current_id(xmmsc_result_t *res, void *userdata)
 	    xmmsc_result_notifier_set(res2, n_media_lib_get_info, &current_id);
 	    xmmsc_result_unref(res2);
 	}
-	xmmsc_result_unref(res);
+	return TRUE;
 }
 
-static void bc_handle_playback_status_change(xmmsc_result_t *res, void *userdata)
+static int bc_handle_playback_status_change(xmmsv_t *val, void *userdata)
 {
-	guint pb_status = 0;
+	gint pb_status = 0;
 
-	if (xmmsc_result_iserror(res))
-		return;
-	if (!xmmsc_result_get_uint(res, &pb_status))
-		return;
+	if (xmmsv_is_error(val))
+		return FALSE;
+	if (!xmmsv_get_int(val, &pb_status))
+		return FALSE;
 
 	switch (pb_status) {
 		case XMMS_PLAYBACK_STATUS_PLAY:
@@ -396,23 +392,24 @@ static void bc_handle_playback_status_change(xmmsc_result_t *res, void *userdata
 			control_buttons_set_play_pause_button(&cb, PLAY_BUTTON);
 			break;
 	}
+	return TRUE;
 }
 
-static void n_handle_playback_status(xmmsc_result_t *res, void *userdata)
+static int n_handle_playback_status(xmmsv_t *val, void *userdata)
 {
-	guint pb_status = 0;
+	gint pb_status = 0;
 
-	if (xmmsc_result_iserror(res))
-		return;
-	if (!xmmsc_result_get_uint(res, &pb_status))
-		return;
+	if (xmmsv_is_error(val))
+		return FALSE;
+	if (!xmmsv_get_int(val, &pb_status))
+		return FALSE;
 
 	if (pb_status == XMMS_PLAYBACK_STATUS_PLAY) {
 		control_buttons_set_play_pause_button(&cb, PAUSE_BUTTON);
 	} else {
 		control_buttons_set_play_pause_button(&cb, PLAY_BUTTON);
 	}
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static gboolean cb_timer_connection_lost(gpointer userdata)
@@ -535,7 +532,7 @@ static gchar *plugin_info_text[] =
 {
 "<b>GkrellM XMMS2 Control (gkrellxmms2)\n",
 "Version: ", VERSION_NUMBER, "\n",
-"gkrellxmms2 Copyright (c) 2005-2007 Johannes Heimansberg\n",
+"gkrellxmms2 Copyright (c) 2005-2010 Johannes Heimansberg\n",
 "http://wejp.k.vu/\n\n",
 "<b>Usage:\n",
 "gkrellxmms2 has five buttons to control the XMMS2 audio player.\n",
@@ -550,10 +547,10 @@ static gchar *plugin_info_text[] =
 
 static void create_plugin_tab(GtkWidget *tab_vbox)
 {
-	GtkWidget	*tabs, *text, *label;
-	GtkWidget	*vbox;
-	gint		i;
-	gchar       *about_text;
+	GtkWidget *tabs, *text, *label, *widget;
+	GtkWidget *vbox;
+	gint       i;
+	gchar     *about_text;
 
 	tabs = gtk_notebook_new();
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(tabs), GTK_POS_TOP);
@@ -570,7 +567,7 @@ static void create_plugin_tab(GtkWidget *tab_vbox)
 	about_text = g_strdup_printf(
 		"gkrellxmms2 %s\n"
 		"GKrellM XMMS2 Control Plugin\n\n"
-		"Copyright (c) 2005-2007 Johannes Heimansberg\n"
+		"Copyright (c) 2005-2010 Johannes Heimansberg\n"
 		"http://wejp.k.vu/\n\n"
 		"Released under the GNU General Public License v2.0", 
 		VERSION_NUMBER);
@@ -578,12 +575,25 @@ static void create_plugin_tab(GtkWidget *tab_vbox)
 	label = gtk_label_new("About");
 	gtk_notebook_append_page(GTK_NOTEBOOK(tabs), text, label);
 	g_free(about_text);
+
+	/* Setup tab */
+	label = gtk_label_new("Setup");
+	widget = setup_widget_create(&sw);
+	gtk_notebook_append_page(GTK_NOTEBOOK(tabs), widget, label);
+	setup_widget_set_ipc_path(&sw, config.ipc_path);
+	setup_widget_set_scroll_speed(&sw, config.scroll_speed);
+	setup_widget_set_auto_reconnect(&sw, config.auto_reconnect);
+}
+
+static void apply_config(void)
+{
+	config.scroll_speed = setup_widget_get_scroll_speed(&sw);
+	config.auto_reconnect = setup_widget_get_auto_reconnect(&sw);
+	g_strlcpy(config.ipc_path, setup_widget_get_ipc_path(&sw), sizeof(config.ipc_path));
 }
 
 static void save_config(FILE *f)
 {
-	/* printf("gkrellxmms2: saving config...\n"); */
-
 	if (gml != NULL) {
 		config.medialib_window_width            = gml_window_get_width(GMEDIALIB(gml));
 		config.medialib_window_height           = gml_window_get_height(GMEDIALIB(gml));
@@ -651,10 +661,8 @@ static void load_config(gchar *arg)
 	gchar cfg[64], item[1024];
 	gint  n;
 
-	/* printf("gkrellxmms2: loading config: "); */
 	n = sscanf(arg, "%s %[^\n]", cfg, item);
 	if (n == 2) {
-		/* printf("%s = %s (%d)\n", cfg, item, atoi(item)); */
 		if (strcmp(cfg, "scroll_speed") == 0)
 			config.scroll_speed = atoi(item);
 		if (strcmp(cfg, "medialib_window_width") == 0)
@@ -703,7 +711,7 @@ static GkrellmMonitor	plugin_mon	=
 	create_plugin,         /* The create function      */
 	update_plugin,         /* The update function      */
 	create_plugin_tab,     /* The config tab create function */
-	NULL,                  /* Apply the config function      */
+	apply_config,          /* Apply the config function      */
 
 	save_config,           /* Save user config   */
 	load_config,           /* Load user config   */
