@@ -136,33 +136,31 @@ static gint cb_configure_event(GtkWidget *widget, GdkEvent *event, gpointer pt)
 	return FALSE;
 }
 
-static void bc_handle_mediainfo_reader_status(xmmsc_result_t *res, void *userdata)
+static int bc_handle_mediainfo_reader_status(xmmsv_t *val, void *userdata)
 {
 	GMedialib *gml = (GMedialib *)userdata;
 	gint32     status;
 
-	xmmsc_result_get_int(res, &status);
+	xmmsv_get_int(val, &status);
 	if (status == 0)
 		gml_set_statusbar_text(gml, "Done.");
 	else if (status == 1)
 		gml_set_statusbar_text(gml, "Reading media info of newly added files...");
+	return TRUE;
 }
 
-static void cb_handle_mediainfo_reader_unindexed(xmmsc_result_t *res, void *userdata)
+static int cb_handle_mediainfo_reader_unindexed(xmmsv_t *val, void *userdata)
 {
-	guint32         remaining_files;
+	gint32          remaining_files;
 	gchar           buf[256];
 	GMedialib      *gml = (GMedialib *)userdata;
-	xmmsc_result_t *res2;
 
-	xmmsc_result_get_uint(res, &remaining_files);
+	xmmsv_get_int(val, &remaining_files);
 	snprintf(buf, sizeof(buf), 
 	         "Reading media info of newly added files: %d files remaining",
 	         remaining_files);
 	gml_set_statusbar_text(gml, buf);
-	res2 = xmmsc_result_restart(res);
-	xmmsc_result_unref(res);
-	xmmsc_result_unref(res2);
+	return TRUE;
 }
 
 static gboolean cb_key_press(GtkWidget   *widget,
