@@ -147,7 +147,7 @@ gint       gml_window_get_pos_y(GMedialib *gml);
 gint       gml_window_get_width(GMedialib *gml);
 gint       gml_window_get_height(GMedialib *gml);
 
-void       gml_playlist_n_add_track_with_info(xmmsc_result_t *res2, void *arg);
+int        gml_playlist_n_add_track_with_info(xmmsv_t *val, void *arg);
 
 void       gml_playlist_update_entry(GMedialib *gml, guint pos);
 G_END_DECLS
