@@ -2,7 +2,7 @@
  * File: gmladdfiles.c
  *
  * Medialib search and playlist editor
- * Copyright (c) 2005-2006 Johannes Heimansberg
+ * Copyright (c) 2005-2010 Johannes Heimansberg
  *
  * requires GTK+ 2.6 or better and XMMS2
  *
@@ -21,35 +21,37 @@
 
 extern xmmsc_connection_t *connection; /* available from gxmms2.c */
 
-static void n_playlist_added(xmmsc_result_t *res, void *arg)
+static int n_playlist_added(xmmsv_t *val, void *arg)
 {
-	GMedialib *gml = (GMedialib *)arg;
+	GMedialib  *gml = (GMedialib *)arg;
+	char const *xerr = "Playlist imported successfully.\n";
 
-	if (xmmsc_result_iserror(res)) {
-		gml_set_statusbar_text(gml, (gchar *)xmmsc_result_get_error(res));                                                  
-	} else {
-		gml_set_statusbar_text(gml, "Playlist imported successfully.\n");
-	}
-	xmmsc_result_unref(res);
+	xmmsv_get_error(val, &xerr);
+	gml_set_statusbar_text(gml, (gchar *) xerr);
+	return FALSE;
 }
 
-static void n_idlist_from_playlist_file(xmmsc_result_t *res, void *arg)
+static int n_idlist_from_playlist_file(xmmsv_t *val, void *arg)
 {
 	xmmsc_result_t *res2;
 	xmmsc_coll_t   *coll;
-	const char     *order[] = { "id", NULL };
+	xmmsv_t        *order_v;
+	char           *order[] = { "id", NULL };
+	char const     *xerr;
 
-	if (xmmsc_result_iserror(res))
-		printf("%s\n", xmmsc_result_get_error (res));
+	if (xmmsv_get_error(val, &xerr))
+		printf("%s\n", xerr);
 
-	if (!xmmsc_result_get_collection(res, &coll))
+	if (!xmmsv_get_coll(val, &coll))
 		printf("Couldn't get collection from result!\n");
 
-	res2 = xmmsc_playlist_add_collection(connection, NULL, coll, order);
+	order_v = xmmsv_make_stringlist(order, 1);
+	res2 = xmmsc_playlist_add_collection(connection, NULL, coll, order_v);
+	xmmsv_unref(order_v);
 	xmmsc_result_notifier_set(res2, n_playlist_added, arg);
 
-	xmmsc_result_unref(res);
 	xmmsc_result_unref(res2);
+	return FALSE;
 }
 
 static void cb_add_files(GtkWidget *widget, gpointer pt)
@@ -74,7 +76,7 @@ static void cb_add_files(GtkWidget *widget, gpointer pt)
 			snprintf(url, strlen(fname) + 8, "file://%s", fname);
 
 			if (g_file_test((fname), G_FILE_TEST_IS_DIR)) { /* directory */
-				res = xmmsc_medialib_path_import(connection, url);
+				res = xmmsc_medialib_import_path(connection, url);
 			} else { /* file */
 				if (memcmp(url+(strlen(url)-4), ".pls", 4) == 0 ||
 				    memcmp(url+(strlen(url)-4), ".m3u", 4) == 0) {
