@@ -81,10 +81,11 @@ static void cb_browser_refresh_pressed(GtkWidget *widget, gpointer pt)
 	gml_mlib_browse_update_artists(gml);
 }
 
-static void n_rehash(xmmsc_result_t *res, void *userdata)
+static int n_rehash(xmmsv_t *val, void *userdata)
 {
 	GMedialib *gml = (GMedialib *)userdata;
 	gml_mlib_browse_update_artists(gml);
+	return FALSE;
 }
 
 static void cb_browser_rehash_pressed(GtkWidget *widget, gpointer pt)
@@ -158,14 +159,13 @@ static gboolean cb_browser_selection_popup_menu(GtkWidget *treeview,
 	return TRUE;
 }
 
-static void n_update_artists(xmmsc_result_t *res, void *userdata)
+static int n_update_artists(xmmsv_t *val, void *userdata)
 {
 	GMedialib    *gml = (GMedialib *)userdata;
-	gchar        *artist, *album;
-	gint          id;
 	gchar         artist_tmp[192] = "", album_tmp[192] = "";
 	GtkTreeIter   iter;
 	GtkTreeModel *model;
+	xmmsv_list_iter_t *it;
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(gml->browser.list));
 	/* Make sure the model stays with us after the tree view unrefs it */
@@ -173,14 +173,17 @@ static void n_update_artists(xmmsc_result_t *res, void *userdata)
 	/* Detach model from view */
 	gtk_tree_view_set_model(GTK_TREE_VIEW(gml->browser.list), NULL);
 
-	for (; xmmsc_result_list_valid(res); xmmsc_result_list_next(res)) {
-		xmmsc_result_get_dict_entry_string(res, "artist", &artist);
-		xmmsc_result_get_dict_entry_string(res, "album",  &album);
-		xmmsc_result_get_dict_entry_int(res, "id", &id);
-		if (!artist)
-			artist = "Unknown";
-		if (!album)
-			album = "Unknown";
+	xmmsv_get_list_iter(val, &it);
+	for (; xmmsv_list_iter_valid(it); xmmsv_list_iter_next(it)) {
+		const gchar *artist = "Unknown";
+		const gchar *album = "Unknown";
+		gint id;
+		xmmsv_t *entry;
+
+		xmmsv_list_iter_entry(it, &entry);
+		xmmsv_dict_entry_get_string(entry, "artist", &artist);
+		xmmsv_dict_entry_get_string(entry, "album", &album);
+		xmmsv_dict_entry_get_int(entry, "id", &id);
 		if (g_ascii_strcasecmp(artist, artist_tmp) != 0) {
 			g_strlcpy(artist_tmp, artist, sizeof(artist_tmp));
 			g_strlcpy(album_tmp, album, sizeof(artist_tmp));
@@ -209,16 +212,17 @@ static void n_update_artists(xmmsc_result_t *res, void *userdata)
 	gtk_tree_view_set_model(GTK_TREE_VIEW(gml->browser.list), model);
 	g_object_unref(model);
 
-	xmmsc_result_unref(res);
 	gml_set_statusbar_text(gml, "Ready.");
+	return FALSE;
 }
 
 void gml_mlib_browse_update_artists(GMedialib *gml)
 {
 	xmmsc_result_t *res;
 	xmmsc_coll_t   *universe;
-	const gchar    *properties[] = { "artist", "album", NULL };
-	const gchar    *group_by[]   = { "album", NULL };
+	gchar          *properties[] = { "artist", "album", NULL };
+	gchar          *group_by[]   = { "album", NULL };
+	xmmsv_t        *properties_v, *group_by_v;
 
 	gml_set_statusbar_text(gml, "Loading artists...");
 
@@ -227,8 +231,12 @@ void gml_mlib_browse_update_artists(GMedialib *gml)
 	}
 
 	universe = xmmsc_coll_universe();
-	res = xmmsc_coll_query_infos(connection, universe, properties,
-	                             0, 0, properties, group_by);
+	properties_v = xmmsv_make_stringlist(properties, 2);
+	group_by_v = xmmsv_make_stringlist(group_by, 1);
+	res = xmmsc_coll_query_infos(connection, universe, properties_v,
+	                             0, 0, properties_v, group_by_v);
+	xmmsv_unref(properties_v);
+	xmmsv_unref(group_by_v);
 	xmmsc_result_notifier_set(res, n_update_artists, gml);
 	xmmsc_coll_unref(universe);
 	xmmsc_result_unref(res);
