@@ -2,9 +2,9 @@
  * File: gmlbrowser.h
  *
  * Medialib search and playlist editor
- * Copyright (c) 2005 Johannes Heimansberg
+ * Copyright (c) 2005-2007 Johannes Heimansberg
  *
- * requires GTK+ 2.6 or better and XMMS2 DR2 or better
+ * requires GTK+ 2.6 or better and XMMS2
  *
  * Released under the GNU General Public License v2
  */
@@ -17,6 +17,10 @@
 struct _GMLBrowser
 {
 	GtkWidget    *frame, *table;
+	GtkWidget    *button_refresh, *image_refresh;
+	GtkWidget    *button_rehash,  *image_rehash;
+	GtkWidget    *button_expand_all,   *image_expand_all;
+	GtkWidget    *button_collapse_all, *image_collapse_all;
 	GtkWidget    *list,  *scroll_widget;
 	GtkWidget    *button_search;
 	GtkTreeStore *ts;
