@@ -2,7 +2,7 @@
  * File: gmlplaylist.c
  *
  * Medialib search and playlist editor
- * Copyright (c) 2005-2007 Johannes Heimansberg
+ * Copyright (c) 2005-2009 Johannes Heimansberg
  *
  * requires GTK+ 2.6 or better and XMMS2
  *
@@ -32,32 +32,31 @@
 extern xmmsc_connection_t *connection; /* available from gxmms2.c */
 static GdkAtom drag_atom;
 
-static void update_pl_entry(xmmsc_result_t *res,  void   *gmlptr, 
-                            GtkTreeIter    *iter, gint32  pos)
+static void update_pl_entry(xmmsv_t     *val,  void   *gmlptr, 
+                            GtkTreeIter *iter, gint32  pos)
 {
 	gint32        id;
 	static gint32 last_pos = -2;
 	GMedialib    *gml = (GMedialib *)gmlptr;
-	gchar        *url, *filename = "", *artist_tmp = "", *title_tmp = "";
-	gchar        *album, *artist = NULL, *title = NULL, *channel = NULL;
-	gchar        *prefix = "", *url_utf8;
-	const gchar  *url_tmp;
+	const gchar  *url, *artist_tmp = NULL, *title_tmp = NULL, *channel;
+	const gchar  *album = "[Unknown Album]";
+	gchar        *filename;
+	gchar        *artist = NULL, *title = NULL, *prefix = "", *url_utf8;
 	gchar         album_with_tracknr[256];
 	gint          tracknr = -1, rating = -1;
 	static gchar  last_title[256] = "", last_artist[256] = "";
 
-	xmmsc_result_get_dict_entry_string(res, "artist",  &artist_tmp);
-	xmmsc_result_get_dict_entry_string(res, "title",   &title_tmp);
-	xmmsc_result_get_dict_entry_string(res, "album",   &album);
-	xmmsc_result_get_dict_entry_int(res,    "id",      &id);
-	xmmsc_result_get_dict_entry_string(res, "url",     &url);
-	xmmsc_result_get_dict_entry_int(res,    "tracknr", &tracknr);
-	xmmsc_result_get_dict_entry_int(res,    "rating",  &rating);
-	if (xmmsc_result_get_dict_entry_string(res, "channel", &channel)) {
+	xmmsv_dict_entry_get_string(val, "artist",  &artist_tmp);
+	xmmsv_dict_entry_get_string(val, "title",   &title_tmp);
+	xmmsv_dict_entry_get_string(val, "album",   &album);
+	xmmsv_dict_entry_get_int(val,    "id",      &id);
+	xmmsv_dict_entry_get_string(val, "url",     &url);
+	xmmsv_dict_entry_get_int(val,    "tracknr", &tracknr);
+	xmmsv_dict_entry_get_int(val,    "rating",  &rating);
+	if (xmmsv_dict_entry_get_string(val, "channel", &channel)) {
 		prefix = "[Stream] ";
 		album = channel;
-	} else if (album == NULL)
-		album = "[Unknown Album]";
+	}
 
 	rating--;
 
@@ -70,8 +69,7 @@ static void update_pl_entry(xmmsc_result_t *res,  void   *gmlptr,
 		snprintf(album_with_tracknr, 256, "%s", album);
 
 	if (url) {
-		url_tmp = xmmsc_result_decode_url(res, url);
-		url_utf8 = get_valid_utf8_str_alloc(url_tmp);
+		url_utf8 = decode_url(url);
 		filename = g_path_get_basename(url_utf8);
 		g_free(url_utf8);
 	} else {
@@ -122,20 +120,23 @@ static void update_pl_entry(xmmsc_result_t *res,  void   *gmlptr,
 
 	if (url)
 		g_free(filename);
-
-	xmmsc_result_unref(res);
 }
 
-void gml_playlist_n_add_track_with_info(xmmsc_result_t *res2, void *gmlptr)
+int gml_playlist_n_add_track_with_info(xmmsv_t *val, void *gmlptr)
 {
+	static const char *pref[] = { "client/generic", "server", "plugins/*",
+	                              "client/*", "*", NULL };
 	guint               pos;
 	gint32              id;
 	static GtkTreeIter  iter;
 	GMedialib          *gml = (GMedialib *)gmlptr;
+	xmmsv_t            *info;
 
 	pos = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(gml->playlist.ls), NULL);
 
-	xmmsc_result_get_dict_entry_int(res2, "id", &id);
+	info = xmmsv_propdict_to_dict(val, pref);
+
+	xmmsv_dict_entry_get_int(info, "id", &id);
 
 	if (gml->playlist.ls != NULL) {
 		gtk_list_store_append(gml->playlist.ls, &iter);
@@ -143,37 +144,40 @@ void gml_playlist_n_add_track_with_info(xmmsc_result_t *res2, void *gmlptr)
 		                   0, pos, 1, id, -1);
 	}
 
-	update_pl_entry(res2, gml, &iter, pos);
+	update_pl_entry(info, gml, &iter, pos);
 	if (gml->playlist.refresh == TRUE) {
 		gml->playlist.refresh_counter--;
 		if (gml->playlist.refresh_counter == 0) gml->playlist.refresh = FALSE;
 	}
+	xmmsv_unref(info);
+	return FALSE;
 }
 
-static void n_pl_playlist_list(xmmsc_result_t *res, void *userdata)
+static int n_pl_playlist_list(xmmsv_t *val, void *userdata)
 {
 	GMedialib   *gml = (GMedialib *)userdata;
-	static const char *pref[] = { "client/generic", "server", "plugins/*",
-	                              "client/*", "*", NULL };
 
 	if (gml->playlist.refresh_counter == 0) {
+		xmmsv_list_iter_t *it;
 		gml->playlist.refresh = TRUE;
-		for (; xmmsc_result_list_valid(res); xmmsc_result_list_next(res)) {
+		xmmsv_get_list_iter(val, &it);
+		for (; xmmsv_list_iter_valid(it); xmmsv_list_iter_next(it)) {
+			xmmsv_t        *entry;
 			xmmsc_result_t *res2;
-			guint           i;
+			gint            i;
 
-			if (!xmmsc_result_get_uint(res, &i))
+			xmmsv_list_iter_entry(it, &entry);
+			if (!xmmsv_get_int(entry, &i))
 				printf("Broken result\n");
 
 			gml->playlist.refresh_counter++;
 			res2 = xmmsc_medialib_get_info(connection, i);
-			xmmsc_result_source_preference_set(res2, pref);
 			xmmsc_result_notifier_set(res2, gml_playlist_n_add_track_with_info, gml);
 			xmmsc_result_unref(res2);
 		}
 	}
-	xmmsc_result_unref(res);
 	gml_set_statusbar_text(gml, "Ready.");
+	return FALSE;
 }
 
 void gml_pl_refresh_playlist(GMedialib *gml)
@@ -194,41 +198,43 @@ void gml_pl_refresh_playlist(GMedialib *gml)
 	}
 }
 
-static void n_pl_update_current_pos(xmmsc_result_t *res, void *arg)
+static int n_pl_update_current_pos(xmmsv_t *val, void *arg)
 {
-	guint      pos = 0;
+	gint       pos = 0;
 	GMedialib *gml = (GMedialib *)arg;
 
-	xmmsc_result_get_uint(res, &pos);
+	xmmsv_dict_entry_get_int(val, "position", &pos);
 	gml->playlist.current_pos = pos;
 	if (gml->playlist.move_finished)
 		gml_playlist_update_entry(gml, gml->playlist.current_pos);
 	gtk_widget_queue_draw(gml->playlist.list);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
-static void bc_handle_current_id(xmmsc_result_t *res, void *userdata)
+static int bc_handle_current_id(xmmsv_t *val, void *userdata)
 {
 	xmmsc_result_t *res2;
 
 	res2 = xmmsc_playlist_current_pos(connection, NULL);
 	xmmsc_result_notifier_set(res2, n_pl_update_current_pos, userdata);
 	xmmsc_result_unref(res2);
+	return TRUE;
 }
 
-static void bc_handle_medialib_entry_changed(xmmsc_result_t *res, void *gmlptr)
+static int bc_handle_medialib_entry_changed(xmmsv_t *val, void *gmlptr)
 {
 	GMedialib *gml = GMEDIALIB(gmlptr);
 
 	if (gml->playlist.move_finished)
 		gml_playlist_update_entry(gml, gml->playlist.current_pos);
+	return TRUE;
 }
 
-static void bc_handle_playlist_changed(xmmsc_result_t *res, void *gmlptr)
+static int bc_handle_playlist_changed(xmmsv_t *val, void *gmlptr)
 {
 	GMedialib    *gml = GMEDIALIB(gmlptr);
-	gint          signal, pl_length, pos_del = -1, pos_ins = -1, pos = -1;
-	guint         id, counter;
+	gint          id, signal, pl_length, pos_del = -1, pos_ins = -1, pos = -1;
+	guint         counter;
 	GtkTreeIter   iter;
 	GtkTreeModel *model;
 
@@ -236,10 +242,10 @@ static void bc_handle_playlist_changed(xmmsc_result_t *res, void *gmlptr)
 	pl_length = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(gml->playlist.ls),
 		                                       NULL);
 
-	xmmsc_result_get_dict_entry_int(res, "type", &signal);
+	xmmsv_dict_entry_get_int(val, "type", &signal);
 	switch (signal) {
 		case XMMS_PLAYLIST_CHANGED_ADD:
-			xmmsc_result_get_dict_entry_uint(res, "id", &id);
+			xmmsv_dict_entry_get_int(val, "id", &id);
 
 			/* add item to gtk list */
 			if (gml->playlist.ls != NULL) {
@@ -250,8 +256,8 @@ static void bc_handle_playlist_changed(xmmsc_result_t *res, void *gmlptr)
 			}
 			break;
 		case XMMS_PLAYLIST_CHANGED_INSERT:
-			xmmsc_result_get_dict_entry_uint(res, "id", &id);
-			xmmsc_result_get_dict_entry_int(res, "position", &pos_ins);
+			xmmsv_dict_entry_get_int(val, "id", &id);
+			xmmsv_dict_entry_get_int(val, "position", &pos_ins);
 			if (gml->playlist.ls != NULL) {
 				gtk_list_store_insert(gml->playlist.ls, &iter, pos_ins);
 				gtk_list_store_set(gml->playlist.ls, &iter, 
@@ -272,7 +278,7 @@ static void bc_handle_playlist_changed(xmmsc_result_t *res, void *gmlptr)
 			gml_pl_refresh_playlist(gml);
 			break;
 		case XMMS_PLAYLIST_CHANGED_REMOVE:
-			xmmsc_result_get_dict_entry_int(res, "position", &pos_del);
+			xmmsv_dict_entry_get_int(val, "position", &pos_del);
 			if (gml->playlist.ls != NULL) {
 				model = GTK_TREE_MODEL(gml->playlist.ls);
 
@@ -303,6 +309,7 @@ static void bc_handle_playlist_changed(xmmsc_result_t *res, void *gmlptr)
 		case XMMS_PLAYLIST_CHANGED_MOVE:
 			break;
 	}
+	return TRUE;
 }
 
 
@@ -362,36 +369,39 @@ static void pl_cell_data_function(GtkTreeViewColumn *col,
 		g_object_set(renderer, "weight-set", FALSE, NULL);
 }
 
-static void n_tickle(xmmsc_result_t *res, void *userdata)
+static int n_tickle(xmmsv_t *val, void *userdata)
 {
-	GMedialib *gml = (GMedialib *)userdata;
-	if (xmmsc_result_iserror(res)) {
+	GMedialib  *gml = (GMedialib *)userdata;
+	char const *xerr;
+
+	if (xmmsv_get_error(val, &xerr)) {
 		gchar buffer[128];
-		snprintf(buffer, 128, "ERROR: Couldn't jump to that song: %s", 
-		         xmmsc_result_get_error(res));
+		snprintf(buffer, 128, "ERROR: Couldn't jump to that song: %s", xerr);
 		gml_set_statusbar_text(gml, buffer);
 	} else {
 		xmms2ctrl_play(connection);
 		gml_set_statusbar_text(gml, "Ready.");
-		xmmsc_result_unref(res);
 	}
+	return FALSE;
 }
 
-static void n_jump_to_track(xmmsc_result_t *res, void *userdata)
+static int n_jump_to_track(xmmsv_t *val, void *userdata)
 {
-	GMedialib *gml = (GMedialib *)userdata;
-	if (xmmsc_result_iserror(res)) {
+	GMedialib  *gml = (GMedialib *)userdata;
+	char const *xerr;
+
+	if (xmmsv_get_error(val, &xerr)) {
 		gchar buffer[128];
-		snprintf(buffer, 128, "ERROR: Couldn't jump to that song: %s", 
-		         xmmsc_result_get_error(res));
+		snprintf(buffer, 128, "ERROR: Couldn't jump to that song: %s",
+		         xerr);
 		gml_set_statusbar_text(gml, buffer);
 	} else {
 		xmmsc_result_t *res2;
 		res2 = xmmsc_playback_tickle(connection);
 		xmmsc_result_notifier_set(res2, n_tickle, userdata);
 		xmmsc_result_unref(res2);
-		xmmsc_result_unref(res);
 	}
+	return FALSE;
 }
 
 static void cb_pl_on_tree_view_row_activated(GtkTreeView       *view, 
@@ -425,7 +435,7 @@ struct params_2
 	guint     direction;
 };
 
-static void n_playlist_move(xmmsc_result_t *res, void *arguments)
+static int n_playlist_move(xmmsv_t *val, void *arguments)
 {
 	struct params_2  *p = (struct params_2 *)arguments;
 	GtkTreeSelection *sel = 
@@ -441,6 +451,7 @@ static void n_playlist_move(xmmsc_result_t *res, void *arguments)
 	gchar            *other_artist = NULL, *other_track = NULL;
 	gchar            *other_album = NULL;
 	GdkPixbuf        *icon_rank, *icon_other_rank;
+	char const       *xerr;
 
 	gtk_tree_model_get_iter(GTK_TREE_MODEL(p->gml->playlist.ls),
 	                        &selected_row, path);
@@ -448,10 +459,10 @@ static void n_playlist_move(xmmsc_result_t *res, void *arguments)
 	                                         2, &artist, 3, &track, 
 	                                         4, &album,  5, &icon_rank, -1);
 
-	if (xmmsc_result_iserror(res)) {
+	if (xmmsv_get_error(val, &xerr)) {
 		gchar buf[128];
 		snprintf(buf, 128, "Unable to move playlist entry: %s",
-		        xmmsc_result_get_error(res));
+		         xerr);
 		gml_set_statusbar_text(p->gml, buf);
 	} else {
 		if (p->direction == DOWN)
@@ -514,7 +525,7 @@ static void n_playlist_move(xmmsc_result_t *res, void *arguments)
 	g_list_free(list);
 	update_current_pl_pos(p->gml);
 	g_free(p);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void pl_move_item(GMedialib *gml, guint direction)
@@ -548,12 +559,12 @@ static void pl_move_item(GMedialib *gml, guint direction)
 	}
 }
 
-static void n_shuffle_or_sort_ready(xmmsc_result_t *res, void *userdata)
+static int n_shuffle_or_sort_ready(xmmsv_t *val, void *userdata)
 {
 	GMedialib *gml = (GMedialib *)userdata;
 
 	update_current_pl_pos(gml);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void cb_pl_shuffle_button_pressed(GtkWidget *widget, gpointer userdata)
@@ -606,15 +617,17 @@ static gboolean cb_pl_sort_button_raw_pressed(GtkWidget      *widget,
 static void cb_pl_sort_menu_activate(GtkMenuItem *menuitem, gpointer userdata)
 {
 	xmmsc_result_t *res;
-	const gchar    *sortby[2];
+	gchar          *sortby;
+	xmmsv_t        *sortprop;
 
-	sortby[0] = (const gchar*)g_utf8_strdown(
-	                          gtk_label_get_label(GTK_LABEL(
-	                          gtk_bin_get_child(GTK_BIN(menuitem)))), -1);
-	sortby[1] = 0;
+	sortby = g_utf8_strdown(
+		gtk_label_get_label(GTK_LABEL(
+		gtk_bin_get_child(GTK_BIN(menuitem)))), -1);
+	sortprop = xmmsv_make_stringlist(&sortby, 1);
 
-	res = xmmsc_playlist_sort(connection, NULL, sortby);
-	g_free((gpointer)sortby[0]);
+	res = xmmsc_playlist_sort(connection, NULL, sortprop);
+	xmmsv_unref(sortprop);
+	g_free(sortby);
 	xmmsc_result_notifier_set(res, n_shuffle_or_sort_ready, userdata);
 	xmmsc_result_unref(res);
 }
@@ -625,19 +638,24 @@ struct params_entry_update {
 	gint32       pos;
 };
 
-static void n_update_playlist_entry(xmmsc_result_t *res, void *arg)
+static int n_update_playlist_entry(xmmsv_t *val, void *arg)
 {
 	struct params_entry_update *p = (struct params_entry_update *)arg;
 	GtkTreeIter                 iter;
+	char const                 *xerr;
 
 	iter = p->iter;
 
-	if (xmmsc_result_iserror(res))
-		printf("%s\n", xmmsc_result_get_error(res));
-	else
-		update_pl_entry(res, p->gml, &iter, p->pos);
+	if (xmmsv_get_error(val, &xerr))
+		printf("%s\n", xerr);
+	else {
+		xmmsv_t *info = xmmsv_propdict_to_dict(val, NULL);
+		update_pl_entry(info, p->gml, &iter, p->pos);
+		xmmsv_unref(info);
+	}
 
 	g_free(p);
+	return FALSE;
 }
 
 void gml_playlist_update_entry(GMedialib *gml, guint pos)
@@ -646,8 +664,6 @@ void gml_playlist_update_entry(GMedialib *gml, guint pos)
 	GtkTreeModel      *model = GTK_TREE_MODEL(gml->playlist.ls);
 	GtkTreeIter        iter;
 	guint              poscnt = 0;
-	static const char *pref[] = { "client/generic", "server", "plugins/*",
-	                              "client/*", "*", NULL };
 
 	p->gml = gml;
 
@@ -661,7 +677,6 @@ void gml_playlist_update_entry(GMedialib *gml, guint pos)
 				p->iter = iter;
 				p->pos  = pos;
 				res = xmmsc_medialib_get_info(connection, id);
-				xmmsc_result_source_preference_set(res, pref);
 				xmmsc_result_notifier_set(res, n_update_playlist_entry, p);
 				xmmsc_result_unref(res);
 			}
@@ -670,14 +685,13 @@ void gml_playlist_update_entry(GMedialib *gml, guint pos)
 	}
 }
 
-static void n_idlist_ready(xmmsc_result_t *res, void *pt)
+static int n_idlist_ready(xmmsv_t *val, void *pt)
 {
 	xmmsc_result_t *res2;
-	int             i, j, cnt_item = 0, length = 0, rnd[10];
+	int             i, j, cnt_item = 0, length, rnd[10];
+	xmmsv_list_iter_t *it;
 
-	for (; xmmsc_result_list_valid(res); xmmsc_result_list_next(res)) {
-		length++;
-	}
+	length = xmmsv_list_get_size(val);
 	/* create ten random numbers between 0 and length: */
 	srand(time(NULL));
 	for (i = 0; i < 10; i++)
@@ -692,11 +706,13 @@ static void n_idlist_ready(xmmsc_result_t *res, void *pt)
 			}
 
 	i = 0;
-	xmmsc_result_list_first(res);
-	for (; xmmsc_result_list_valid(res); xmmsc_result_list_next(res)) {
-		guint id;
+	xmmsv_get_list_iter(val, &it);
+	for (; xmmsv_list_iter_valid(it); xmmsv_list_iter_next(it)) {
+		xmmsv_t *entry;
+		gint     id;
 
-		if (!xmmsc_result_get_uint(res, &id)) {
+		xmmsv_list_iter_entry(it, &entry);
+		if (!xmmsv_get_int(entry, &id)) {
 			printf("gxmms2: Broken resultset.\n");
 		}
 		if (cnt_item < 10 && i == rnd[cnt_item]) {
@@ -706,7 +722,7 @@ static void n_idlist_ready(xmmsc_result_t *res, void *pt)
 		}
 		i++;
 	}
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void cb_pl_add_rnd_button_pressed(GtkWidget *widget, gpointer userdata)
@@ -747,13 +763,14 @@ static gint comp_func(gconstpointer a, gconstpointer b)
 	return (*(guint *)a > *(guint *)b ? -1 : 1);
 }
 
-static void n_playlist_remove(xmmsc_result_t *res, void *arguments)
+static int n_playlist_remove(xmmsv_t *val, void *arguments)
 {
-	if (xmmsc_result_iserror(res)) {
-		fprintf(stderr, "Couldn't remove item (%s)\n", 
-		        xmmsc_result_get_error(res));
+	char const *xerr;
+
+	if (xmmsv_get_error(val, &xerr)) {
+		fprintf(stderr, "Couldn't remove item (%s)\n", xerr);
 	}
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void cb_pl_button_delete_pressed(GtkWidget *widget, gpointer userdata)
@@ -826,16 +843,16 @@ static void pl_play_selection(GtkTreeModel  *model,
 	xmmsc_result_unref(res);
 }
 
-static void n_media_lib_get_info(xmmsc_result_t *res, void *arg)
+static int n_media_lib_get_info(xmmsv_t *val, void *arg)
 {
 	trackinfo  track;
 	GtkWidget *dialog;
 
-	trackinfo_update(res, &track);
+	trackinfo_update(val, &track);
 	dialog = gtrackinfo_new();
 	gtrackinfo_set_info(GTRACKINFO(dialog), &track);
 	gtk_widget_show(dialog);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void pl_info_about_selection(GtkTreeModel  *model,
@@ -858,14 +875,13 @@ struct params
 	GtkTreeIter  iter;
 };
 
-static void n_playlist_current_pos(xmmsc_result_t *res, void *arguments)
+static int n_playlist_current_pos(xmmsv_t *val, void *arguments)
 {
 	struct params *pm = (struct params *)arguments;
-	guint          pos = 0, p = 0;
+	gint           pos = 0, p = 0;
 	GtkTreePath   *path;
 
-	xmmsc_result_get_uint(res, &pos);
-	xmmsc_result_unref(res);
+	xmmsv_dict_entry_get_int(val, "position", &pos);
 	pm->gml->playlist.current_pos = pos;
 
 	gtk_tree_model_get(GTK_TREE_MODEL(pm->gml->playlist.ls), 
@@ -885,6 +901,7 @@ static void n_playlist_current_pos(xmmsc_result_t *res, void *arguments)
 	                             path, NULL, TRUE, 0.5, 0.5);
 	gtk_tree_path_free(path);
 	g_free(pm);
+	return FALSE;
 }
 
 static void cb_pl_button_track_pressed(GtkWidget *widget, gpointer userdata)
@@ -905,21 +922,21 @@ static void cb_pl_button_track_pressed(GtkWidget *widget, gpointer userdata)
 
 static void cb_pl_save_pl_button_pressed(GtkWidget *widget, gpointer userdata);
 
-static void n_playlist_loaded(xmmsc_result_t *res, void *userdata)
+static int n_playlist_loaded(xmmsv_t *val, void *userdata)
 {
 	GMedialib *gml = (GMedialib *)userdata;
 	gml_pl_refresh_playlist(gml);
 	gml_set_statusbar_text(gml, "Ready.");
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
-static void n_playlist_clear(xmmsc_result_t *res, void *userdata)
+static int n_playlist_clear(xmmsv_t *val, void *userdata)
 {
 	xmmsc_result_t *res2;
 	res2 = xmmsc_playlist_load(connection, "_gxmms2_tmp_list");
 	xmmsc_result_notifier_set(res2, n_playlist_loaded, userdata);
 	xmmsc_result_unref(res2);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void cb_pl_clear_button_pressed(GtkWidget *widget, gpointer userdata)
@@ -968,16 +985,18 @@ static void cb_pl_clear_button_pressed(GtkWidget *widget, gpointer userdata)
 	}
 }
 
-static void n_playlist_save(xmmsc_result_t *res, void *userdata)
+static int n_playlist_save(xmmsv_t *val, void *userdata)
 {
-	GMedialib *gml = (GMedialib *)userdata;
-	if (xmmsc_result_iserror(res)) {
-		gml_set_statusbar_text(gml, (gchar *)xmmsc_result_get_error(res));
+	GMedialib  *gml = (GMedialib *)userdata;
+	char const *xerr;
+
+	if (xmmsv_get_error(val, &xerr)) {
+		gml_set_statusbar_text(gml, (gchar *) xerr);
 	} else {
 		gml_playlists_update_playlists(gml);
 		gml_set_statusbar_text(gml, "Playlist saved successfully.");
 	}
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 struct params_save_pl
@@ -986,16 +1005,18 @@ struct params_save_pl
 	gchar     *pl_name_str;
 };
 
-static void n_coll_get(xmmsc_result_t *res, void *userdata)
+static int n_coll_get(xmmsv_t *val, void *userdata)
 {
-	GMedialib *gml = ((struct params_save_pl *)userdata)->gml;;
-	if (xmmsc_result_iserror(res)) {
-		gml_set_statusbar_text(gml, (gchar *)xmmsc_result_get_error(res));
+	GMedialib  *gml = ((struct params_save_pl *)userdata)->gml;;
+	char const *xerr;
+
+	if (xmmsv_get_error(val, &xerr)) {
+		gml_set_statusbar_text(gml, (gchar *) xerr);
 	} else {
 		xmmsc_coll_t   *playlist_coll;
 		xmmsc_result_t *res2;
 
-		xmmsc_result_get_collection(res, &playlist_coll);
+		xmmsv_get_coll(val, &playlist_coll);
 		res2 = xmmsc_coll_save(connection, playlist_coll,
 		                       ((struct params_save_pl *)userdata)->pl_name_str,
 		                       XMMS_COLLECTION_NS_PLAYLISTS);
@@ -1003,7 +1024,7 @@ static void n_coll_get(xmmsc_result_t *res, void *userdata)
 		xmmsc_coll_unref(playlist_coll);
 	}
 	g_free(((struct params_save_pl *)userdata)->pl_name_str);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void cb_pl_save_pl_button_pressed(GtkWidget *widget, gpointer userdata)
