@@ -26,19 +26,21 @@ struct pl_params
 	gchar     name[256];
 };
 
-static void n_query_playlists(xmmsc_result_t *res, void *pt)
+static int n_query_playlists(xmmsv_t *val, void *pt)
 {
 	struct pl_params *p = (struct pl_params *)pt;
 	xmmsc_coll_t     *coll, *operand;
-	GtkTreeIter      iter;
+	GtkTreeIter       iter;
+	char const       *xerr;
 
-	if (xmmsc_result_iserror(res)) {
-		gml_set_statusbar_text(p->gml, (gchar *)xmmsc_result_get_error(res));
+	if (xmmsv_get_error(val, &xerr)) {
+		gml_set_statusbar_text(p->gml, (gchar *) xerr);
 	} else {
-		gint   cnt = 0;
-		gchar *pl_type = NULL, buf[512];
+		xmmsv_t *v;
+		gint     cnt = 0;
+		gchar   *pl_type = NULL, buf[512];
 
-		xmmsc_result_get_collection(res, &coll);
+		xmmsv_get_coll(val, &coll);
 		cnt = xmmsc_coll_idlist_get_size(coll);
 		switch (xmmsc_coll_get_type (coll)) {
 			case XMMS_COLLECTION_TYPE_IDLIST:
@@ -49,16 +51,16 @@ static void n_query_playlists(xmmsc_result_t *res, void *pt)
 				break;
 			case XMMS_COLLECTION_TYPE_PARTYSHUFFLE:
 				pl_type = "Party shuffle";
-				xmmsc_coll_operand_list_first (coll);
-				if (xmmsc_coll_operand_list_entry (coll, &operand)) {
-					if (xmmsc_coll_get_type(operand) == XMMS_COLLECTION_TYPE_REFERENCE) {
-						gchar *reference;
-						xmmsc_coll_attribute_get(operand, "reference", &reference);
-						snprintf(buf, 511,
-						         "Party shuffle (Source collection: %s)",
-						         reference);
-						pl_type = buf;
-					}
+				if (    xmmsv_list_get (xmmsv_coll_operands_get (coll), 0, &v)
+				    &&  xmmsv_get_coll (v, &operand)
+				    &&  xmmsv_coll_get_type (operand) == XMMS_COLLECTION_TYPE_REFERENCE)
+				{
+					gchar *reference;
+					xmmsc_coll_attribute_get(operand, "reference", &reference);
+					snprintf(buf, 511,
+						 "Party shuffle (Source collection: %s)",
+						 reference);
+					pl_type = buf;
 				}
 				break;
 			default:
@@ -77,24 +79,29 @@ static void n_query_playlists(xmmsc_result_t *res, void *pt)
 		}
 	}
 	g_free(p);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
-static void n_update_playlists(xmmsc_result_t *res, void *pt)
+static int n_update_playlists(xmmsv_t *val, void *pt)
 {
 	GMedialib        *gml = (GMedialib *)pt;
 	struct pl_params *p;
+	char const       *xerr;
 
-	if (xmmsc_result_iserror(res)) {
-		gml_set_statusbar_text(gml, (gchar *)xmmsc_result_get_error(res));
+	if (xmmsv_get_error(val, &xerr)) {
+		gml_set_statusbar_text(gml, (gchar *) xerr);
 	} else {
+		xmmsv_list_iter_t *it;
 		if (gml->playlists.ls != NULL)
 			gtk_list_store_clear(gml->playlists.ls);
-		for (; xmmsc_result_list_valid(res); xmmsc_result_list_next(res)) {
-			gchar          *name;
-			xmmsc_result_t 		*res2;
+		xmmsv_get_list_iter(val, &it);
+		for (; xmmsv_list_iter_valid(it); xmmsv_list_iter_next(it)) {
+			xmmsv_t *entry;
+			const gchar    *name;
+			xmmsc_result_t *res2;
 
-			xmmsc_result_get_string(res, &name);
+			xmmsv_list_iter_entry(it, &entry);
+			xmmsv_get_string(entry, &name);
 
 			p = g_malloc(sizeof(struct pl_params));
 			p->gml = gml;
@@ -107,7 +114,7 @@ static void n_update_playlists(xmmsc_result_t *res, void *pt)
 		}
 		gml_set_statusbar_text(gml, "Ready.");
 	}
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 void gml_playlists_update_playlists(GMedialib *gml)
@@ -119,14 +126,14 @@ void gml_playlists_update_playlists(GMedialib *gml)
 	xmmsc_result_unref(res);
 }
 
-static void n_playlist_load(xmmsc_result_t *res, void *pt)
+static int n_playlist_load(xmmsv_t *val, void *pt)
 {
 	GMedialib *gml = (GMedialib *)pt;
 
 	gml_set_statusbar_text(gml, "Ready.");
 	gml_pl_refresh_playlist(gml);
 	gtk_notebook_set_current_page(GTK_NOTEBOOK(gml->notebook), 4);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void cb_playlists_list_activated(GtkTreeView       *view,
@@ -153,13 +160,13 @@ static void cb_playlists_list_activated(GtkTreeView       *view,
 	}
 }
 
-static void n_playlist_delete(xmmsc_result_t *res, void *pt)
+static int n_playlist_delete(xmmsv_t *val, void *pt)
 {
 	GMedialib *gml = (GMedialib *)pt;
 
 	gml_playlists_update_playlists(gml);
-	xmmsc_result_unref(res);
 	gml_set_statusbar_text(gml, "Ready.");
+	return FALSE;
 }
 
 static void cb_playlists_button_delete_pressed(GtkWidget *widget, gpointer pt)
@@ -210,17 +217,20 @@ static void cb_playlists_button_open_pressed(GtkWidget *widget, gpointer pt)
 	}
 }
 
-static void n_playlist_add_collection(xmmsc_result_t *res, void *pt)
+static int n_playlist_add_collection(xmmsv_t *val, void *pt)
 {
 	GMedialib      *gml = (GMedialib *)pt;
 	xmmsc_coll_t   *playlist_coll;
 	xmmsc_result_t *res2;
+	xmmsv_t        *order;
 
-	xmmsc_result_get_collection(res, &playlist_coll);
-	res2 = xmmsc_playlist_add_collection(connection, "_active",
-	                                     playlist_coll, NULL);
+	xmmsv_get_coll(val, &playlist_coll);
+	order = xmmsv_new_list();
+	res2 = xmmsc_playlist_add_collection(connection, NULL,
+	                                     playlist_coll, order);
+	xmmsv_unref(order);
 	xmmsc_result_notifier_set(res2, n_playlist_load, gml);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void cb_playlists_button_add_pressed(GtkWidget *widget, gpointer pt)
@@ -240,7 +250,8 @@ static void cb_playlists_button_add_pressed(GtkWidget *widget, gpointer pt)
 
 		gtk_tree_model_get(model, &selected_row, 0, &playlist, -1);
 
-		res = xmmsc_coll_get(connection, playlist, "Playlists");
+		res = xmmsc_coll_get(connection, playlist,
+			XMMS_COLLECTION_NS_PLAYLISTS);
 		xmmsc_result_notifier_set(res, n_playlist_add_collection, gml);
 		xmmsc_result_unref(res);
 		g_free(playlist);
