@@ -2,7 +2,7 @@
  * File: gmlsearch.c
  *
  * Medialib search and playlist editor
- * Copyright (c) 2005-2007 Johannes Heimansberg
+ * Copyright (c) 2005-2008 Johannes Heimansberg
  *
  * requires GTK+ 2.6 or better and XMMS2
  *
@@ -125,7 +125,7 @@ static void cb_search_popup_insert_pressed(GtkWidget *widget, gpointer pt)
 
 }
 
-static void n_rehash(xmmsc_result_t *res, void *userdata)
+static int n_rehash(xmmsv_t *val, void *userdata)
 {   
 	struct rehash_notify_data* data = (struct rehash_notify_data *)userdata;
 
@@ -133,6 +133,7 @@ static void n_rehash(xmmsc_result_t *res, void *userdata)
 	
 	if (data->remaining_ids == 0)
 		gmedialib_refresh(data->gml, connection);
+	return FALSE;
 }   
 
 static void cb_search_rehash_button_pressed(GtkWidget *widget, gpointer pt)
@@ -299,16 +300,16 @@ static void cb_search_popup_search_album_pressed(GtkWidget *menuitem,
 	g_list_free(list);
 }
 
-static void n_media_lib_get_info(xmmsc_result_t *res, void *arg)
+static int n_media_lib_get_info(xmmsv_t *val, void *arg)
 {
 	trackinfo  track;
 	GtkWidget *dialog;
 
-	trackinfo_update(res, &track);
+	trackinfo_update(val, &track);
 	dialog = gtrackinfo_new();
 	gtrackinfo_set_info(GTRACKINFO(dialog), &track);
 	gtk_widget_show(dialog);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void search_info_about_selection(GtkTreeModel *model,
@@ -526,8 +527,11 @@ static gboolean cb_search_selection_popup_menu(GtkWidget *treeview,
 	return TRUE;
 }
 
-static void n_add_result_notified(xmmsc_result_t *res, void *arguments)
+static int n_add_result_notified(xmmsv_t *val, void *arguments)
 {
+	static const char *pref[] = { "client/generic", "server", "plugins/*",
+	                              "client/*", "*", NULL };
+
 	struct search_params *arg = (struct search_params*)arguments;
 	gchar                *artist = "[Unknown Artist]";
 	gchar                *album  = "[Unknown Album]";
@@ -537,26 +541,19 @@ static void n_add_result_notified(xmmsc_result_t *res, void *arguments)
 	static gint           tmp_id = -1;
 	GtkTreeIter           iter;
 
-	xmmsc_result_get_dict_entry_int(res,    "id",      &id);
-	xmmsc_result_get_dict_entry_int(res,    "tracknr", &tracknr);
-	xmmsc_result_get_dict_entry_string(res, "title",   &title);
-	xmmsc_result_get_dict_entry_int(res,    "rating",  &rating);
+	val = xmmsv_propdict_to_dict(val, pref);
+	xmmsv_dict_entry_get_int(val,    "id",      &id);
+	xmmsv_dict_entry_get_int(val,    "tracknr", &tracknr);
+	xmmsv_dict_entry_get_int(val,    "rating",  &rating);
 	rating--;
-	if (title) {
-		xmmsc_result_get_dict_entry_string(res, "artist", &artist);
-		if (!artist)
-			artist = "[Unknown Artist]";
-
-		xmmsc_result_get_dict_entry_string(res, "album", &album);
-		if (!album)
-			album = "[Unknown Album]";
+	if (xmmsv_dict_entry_get_string(val, "title", (const gchar **)&title)) {
+		xmmsv_dict_entry_get_string(val, "artist", (const gchar **)&artist);
+		xmmsv_dict_entry_get_string(val, "album", (const gchar **)&album);
 	} else {
 		gchar       *url, *url_utf8;
-		const gchar *url_tmp;
-		xmmsc_result_get_dict_entry_string(res, "url", &url);
+		xmmsv_dict_entry_get_string(val, "url", (const gchar **)&url);
 		if (url) {
-			url_tmp = xmmsc_result_decode_url(res, url);
-			url_utf8 = get_valid_utf8_str_alloc(url_tmp);
+			url_utf8 = decode_url(url);
 			filename = g_path_get_basename(url_utf8);
 			g_free(url_utf8);
 			if (filename) {
@@ -587,14 +584,12 @@ static void n_add_result_notified(xmmsc_result_t *res, void *arguments)
 	}
 	if (filename)
 		g_free(filename);
-	xmmsc_result_unref(res);
+	xmmsv_unref(val);
+	return FALSE;
 }
 
 static void add_results(GList *n, struct search_params *arg)
 {
-	static const char *pref[] = { "client/generic", "server", "plugins/*",
-	                              "client/*", "*", NULL };
-
 	for (; n; n = g_list_next(n)) {
 		gint32			id = 0;
 		xmmsc_result_t 	*res = NULL;
@@ -605,7 +600,6 @@ static void add_results(GList *n, struct search_params *arg)
 		if (id) {
 			res = xmmsc_medialib_get_info(arg->conn, id);
 			xmmsc_result_notifier_set(res, n_add_result_notified, arg);
-			xmmsc_result_source_preference_set(res, pref);
 			xmmsc_result_unref(res);
 		} else {
 			printf("Empty result!\n");
@@ -614,19 +608,24 @@ static void add_results(GList *n, struct search_params *arg)
 	g_list_free(n);
 }
 
-static void n_continue_search(xmmsc_result_t *res, void *arguments)
+static int n_continue_search(xmmsv_t *val, void *arguments)
 {
 	struct search_params *arg = (struct search_params*)arguments;
 	GList                *n = NULL;
+	xmmsv_list_iter_t    *it;
+	char const           *xerr;
 
-	if (xmmsc_result_iserror(res)) {
-		printf("%s\n", xmmsc_result_get_error(res));
+	if (xmmsv_get_error(val, &xerr)) {
+		printf("%s\n", xerr);
 	}
 
-	for (; xmmsc_result_list_valid(res); xmmsc_result_list_next(res)) {
-		guint32 *id = g_malloc(sizeof(guint32));
+	xmmsv_get_list_iter(val, &it);
+	for (; xmmsv_list_iter_valid(it); xmmsv_list_iter_next(it)) {
+		gint32 *id = g_malloc(sizeof(gint32));
+		xmmsv_t *entry;
 
-		if (!xmmsc_result_get_uint(res, id)) {
+		xmmsv_list_iter_entry(it, &entry);
+		if (!xmmsv_get_int(entry, id)) {
 			printf("gxmms2: Broken resultset.\n");
 		}
 
@@ -635,13 +634,13 @@ static void n_continue_search(xmmsc_result_t *res, void *arguments)
 
 	add_results(n, arg);
 	xmmsc_coll_unref(arg->coll_query);
-	xmmsc_result_unref(res);
 
 	gml_set_statusbar_text(arg->gml, "Ready.");
 	gtk_widget_set_sensitive(arg->gml->search.button_search,      TRUE);
 	gtk_widget_set_sensitive(arg->gml->search.entry_searchstring, TRUE);
 	gtk_widget_set_sensitive(arg->gml->search.search_combo,       TRUE);
 	gtk_widget_set_sensitive(arg->gml->search.checkbutton_exact,  TRUE);
+	return FALSE;
 }
 
 gboolean gml_search_get_column_id_visible(GMedialib *gml)
