@@ -30,6 +30,10 @@ struct _GMLSearch
 	gboolean           column_id_visible;
 	gboolean           column_artist_visible, column_track_visible;
 	gboolean           column_album_visible,  column_rating_visible;
+
+	gchar             *last_search_str;
+	gint               last_category;
+	gboolean           last_exact;
 };
 
 #endif
