@@ -1,7 +1,7 @@
 /* 
  * File: trackinfo.c
  *
- * Copyright (c) 2005-2006 Johannes Heimansberg
+ * Copyright (c) 2005-2008 Johannes Heimansberg
  *
  * Released under the GNU General Public License v2
  */
@@ -15,13 +15,35 @@
 #include "xmms2ctrl/xmms2ctrl.h"
 #include "sdecode/sdecode.h"
 
-void trackinfo_update(xmmsc_result_t *res,
+gchar *decode_url(const gchar *url)
+{
+	xmmsv_t *url_v;
+	gchar *res = NULL;
+	url_v = xmmsv_new_string(url);
+	if (url_v) {
+		xmmsv_t *decoded_url_v;
+		decoded_url_v = xmmsv_decode_url(url_v);
+		xmmsv_unref(url_v);
+		if (decoded_url_v) {
+			const unsigned char *burl;
+			unsigned int blen;
+			if (xmmsv_get_bin(decoded_url_v, &burl, &blen)) {
+				res = g_malloc(blen + 1);
+				memcpy(res, burl, blen);
+				res[blen] = '\0';
+			}
+			xmmsv_unref(decoded_url_v);
+		}
+	}
+	return res;
+}
+
+void trackinfo_update(xmmsv_t *val,
                       trackinfo      *track)
 {
 	gint32       bitrate = 0, samplerate = 0, id, playtime = 0, vbr = 0, filesize = 0;
 	gchar       *album, *artist, *channel, *comment, *date;
 	gchar       *genre, *mime,   *title,   *url,     *url_utf8;
-	const gchar *url_tmp;
 
 	track->stream        = FALSE;
 	track->vbr           = FALSE;
@@ -33,47 +55,48 @@ void trackinfo_update(xmmsc_result_t *res,
 	track->no_samplerate = FALSE;
 	track->no_filesize   = FALSE;
 
-	if (!xmmsc_result_get_dict_entry_string(res, "artist", &artist)) {
+	val = xmmsv_propdict_to_dict(val, NULL);
+
+	if (!xmmsv_dict_entry_get_string(val, "artist", (const gchar **)&artist)) {
 		artist = "Unknown";
 		track->no_artist = TRUE;
 	}
-	if (!xmmsc_result_get_dict_entry_string(res, "title",  &title)) {
+	if (!xmmsv_dict_entry_get_string(val, "title",  (const gchar **)&title)) {
 		title = "Unknown";
 		track->no_title = TRUE;
 	}
-	if (!xmmsc_result_get_dict_entry_string(res, "album", &album)) {
+	if (!xmmsv_dict_entry_get_string(val, "album", (const gchar **)&album)) {
 		album = "Unknown";
 		track->no_album = TRUE;
 	}
-	if (!xmmsc_result_get_dict_entry_string(res, "comment", &comment))
+	if (!xmmsv_dict_entry_get_string(val, "comment", (const gchar **)&comment))
 		comment = "";
-	if (!xmmsc_result_get_dict_entry_int(res, "duration", &playtime))
+	if (!xmmsv_dict_entry_get_int(val, "duration", &playtime))
 		track->no_playtime = TRUE;
-	if (!xmmsc_result_get_dict_entry_int(res, "id", &id))
+	if (!xmmsv_dict_entry_get_int(val, "id", &id))
 		id = 0;
-	if (!xmmsc_result_get_dict_entry_string(res, "mime", &mime))
+	if (!xmmsv_dict_entry_get_string(val, "mime", (const gchar **)&mime))
 		mime = "Unknown";
-	if (!xmmsc_result_get_dict_entry_string(res, "genre", &genre))
+	if (!xmmsv_dict_entry_get_string(val, "genre", (const gchar **)&genre))
 		genre = "";
-	if (!xmmsc_result_get_dict_entry_int(res, "bitrate", &bitrate))
+	if (!xmmsv_dict_entry_get_int(val, "bitrate", &bitrate))
 		track->no_bitrate = TRUE;
-	if (!xmmsc_result_get_dict_entry_int(res, "samplerate", &samplerate))
+	if (!xmmsv_dict_entry_get_int(val, "samplerate", &samplerate))
 		track->no_samplerate = TRUE;
-	if (!xmmsc_result_get_dict_entry_int(res, "size", &filesize))
+	if (!xmmsv_dict_entry_get_int(val, "size", &filesize))
 		track->no_filesize = TRUE;
-	if (!xmmsc_result_get_dict_entry_string(res, "url", &url))
+	if (!xmmsv_dict_entry_get_string(val, "url", (const gchar **)&url))
 		url = "";
-	if (!xmmsc_result_get_dict_entry_string(res, "date", &date))
+	if (!xmmsv_dict_entry_get_string(val, "date", (const gchar **)&date))
 		date = "";
-	if (!xmmsc_result_get_dict_entry_string(res, "channel", &channel))
+	if (!xmmsv_dict_entry_get_string(val, "channel", (const gchar **)&channel))
 		channel = "";
 	else
 		track->stream = TRUE;
-	xmmsc_result_get_dict_entry_int(res, "isvbr", &vbr);
+	xmmsv_dict_entry_get_int(val, "isvbr", &vbr);
 	if (vbr == 1) track->vbr = TRUE;
 
-	url_tmp = xmmsc_result_decode_url(res, url);
-	url_utf8 = get_valid_utf8_str_alloc(url_tmp);
+	url_utf8 = decode_url(url);
 
 	g_utf8_strncpy(track->artist,   artist,   sizeof(track->artist));
 	g_utf8_strncpy(track->title,    title,    sizeof(track->title));
@@ -121,6 +144,8 @@ void trackinfo_update(xmmsc_result_t *res,
 		           "%s - %s (%d:%02d)", 
 		           track->artist, track->title, track->min, track->sec);
 	}
+
+	xmmsv_unref(val);
 }
 
 gchar *trackinfo_get_album_str(trackinfo *track)
