@@ -2,16 +2,16 @@
  * File: gxmms2.c
  *
  * gxmms2 - A gtk2 frontend for XMMS2
- * Copyright (c) 2005-2007 Johannes Heimansberg
+ * Copyright (c) 2005-2010 Johannes Heimansberg
  *
  * requires GTK+ 2.6 or better and XMMS2
  *
- * Version: 0.7.0
+ * Version: 0.7.1
  *
  * Released under the GNU General Public License v2
  */
 
-#define VERSION_NUMBER "0.7.0"
+#define VERSION_NUMBER "0.7.1"
 
 #include <stdlib.h>
 #include <string.h>
@@ -89,7 +89,7 @@ static gboolean cb_scale_release_event(GtkWidget      *widget,
 
 	if (xmms2ctrl_get_error() != ERROR_CONNECTION) {
 		res = xmmsc_playback_seek_ms(connection, 
-	          	(guint)gtk_range_get_value(GTK_RANGE(widget)));
+	          	(guint)gtk_range_get_value(GTK_RANGE(widget)), XMMS_PLAYBACK_SEEK_SET);
 		xmmsc_result_unref(res);
 	}
 	update_scale = TRUE;
@@ -108,25 +108,26 @@ static void change_volume(gint volume_change, gint initial_volume)
 	xmms2ctrl_volume_set(connection, volume);
 }
 
-static void bc_handle_volume_change(xmmsc_result_t *res, void *userdata)
+static int bc_handle_volume_change(xmmsv_t *val, void *userdata)
 {
-	guint32 volume;
+	gint32  volume;
 	gchar   buf[64];
 	
-	xmmsc_result_get_dict_entry_uint(res, "left", &volume);
+	xmmsv_dict_entry_get_int(val, "left", &volume);
 	wejpvolume_set_volume(WEJPVOLUME(wv), volume);
 	snprintf(buf, 63, "Volume: %d %%", volume);
 	wejpscroller_shortmessage_show(WEJPSCROLLER(scroller), buf, 50);
+	return FALSE;
 }
 
-static void n_volume_init(xmmsc_result_t *res, void *userdata)
+static int n_volume_init(xmmsv_t *val, void *userdata)
 {
-	guint32 volume;
+	gint32 volume;
 	
-	xmmsc_result_get_dict_entry_uint(res, "left", &volume);
+	xmmsv_dict_entry_get_int(val, "left", &volume);
 	wejpvolume_set_volume(WEJPVOLUME(wv), volume);
 	change_volume(0, volume);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
 static void cb_volume_changed(GtkWidget *widget, GdkEvent *e, gpointer data)
@@ -142,7 +143,7 @@ static void show_gxmms2_about_dialog(void)
 	gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(dialog), 
 	                             VERSION_NUMBER);
 	gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(dialog),
-	                               "Copyright (c) 2005-2007 " \
+	                               "Copyright (c) 2005-2010 " \
 	                               "Johannes Heimansberg");
 	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(dialog),
 	                               "A XMMS2 frontend written in C " \
@@ -378,9 +379,9 @@ static gboolean cb_key_press(GtkWidget   *widget,
 	return result;
 }
 
-static void n_media_lib_get_info(xmmsc_result_t *res, void *arg)
+static int n_media_lib_get_info(xmmsv_t *val, void *arg)
 {
-	trackinfo_update(res, &track);
+	trackinfo_update(val, &track);
 	gtk_range_set_value(GTK_RANGE(scale), 0);
 
 	if (trackinfo_get_playtime(&track) > 0) {
@@ -394,15 +395,15 @@ static void n_media_lib_get_info(xmmsc_result_t *res, void *arg)
 		update_scale = FALSE;
 	}
 	update_title_label(title_str, &track, TRUE);
-	xmmsc_result_unref(res);
+	return FALSE;
 }
 
-static guint current_id;
+static gint current_id;
 
-static void bc_handle_medialib_entry_changed(xmmsc_result_t *res, void *userdata)
+static int bc_handle_medialib_entry_changed(xmmsv_t *val, void *userdata)
 {
-	guint id;
-	if (xmmsc_result_get_uint(res, &id)) { 
+	gint id;
+	if (xmmsv_get_int(val, &id)) { 
 	    if (current_id == id && xmms2ctrl_get_error() != ERROR_CONNECTION) {
 			xmmsc_result_t *res2;
 
@@ -411,11 +412,12 @@ static void bc_handle_medialib_entry_changed(xmmsc_result_t *res, void *userdata
 			xmmsc_result_unref(res2);
 		}
 	}
+	return TRUE;
 }
 
-static void bc_handle_current_id(xmmsc_result_t *res, void *userdata)
+static int bc_handle_current_id(xmmsv_t *val, void *userdata)
 {
-	if (xmmsc_result_get_uint(res, &current_id) && 
+	if (xmmsv_get_int(val, &current_id) && 
 		xmms2ctrl_get_error() != ERROR_CONNECTION) {
 		xmmsc_result_t *res2;
 
@@ -423,11 +425,12 @@ static void bc_handle_current_id(xmmsc_result_t *res, void *userdata)
 		xmmsc_result_notifier_set(res2, n_media_lib_get_info, &current_id);
 		xmmsc_result_unref(res2);
 	}
+	return TRUE;
 }
 
-static void sig_handle_current_id(xmmsc_result_t *res, void *userdata)
+static int sig_handle_current_id(xmmsv_t *val, void *userdata)
 {
-	if (xmmsc_result_get_uint(res, &current_id) && 
+	if (xmmsv_get_int(val, &current_id) && 
 		xmms2ctrl_get_error() != ERROR_CONNECTION) {
 		xmmsc_result_t *res2;
 
@@ -435,26 +438,18 @@ static void sig_handle_current_id(xmmsc_result_t *res, void *userdata)
 		xmmsc_result_notifier_set(res2, n_media_lib_get_info, &current_id);
 		xmmsc_result_unref(res2);
 	}
-	xmmsc_result_unref(res);
+	return TRUE;
 }
 
-static void sig_handle_playtime(xmmsc_result_t *res, void *userdata)
+static int sig_handle_playtime(xmmsv_t *val, void *userdata)
 {
-	xmmsc_result_t *res2;
-	guint          ptime;
+	gint           ptime = 0;
 	gchar          buffer[20];
 	static guint   cnt = 0;
-	guint          seconds_elapsed, seconds_remaining, seconds_total;
+	gint           seconds_elapsed, seconds_remaining, seconds_total;
 
-	if (xmms2ctrl_get_error() != ERROR_CONNECTION) {
-		if (xmmsc_result_iserror(res))
-			return;
-		if (!xmmsc_result_get_uint(res, &ptime))
-			return;
-
-		res2 = xmmsc_result_restart(res);
-		xmmsc_result_unref(res2);
-		xmmsc_result_unref(res);
+	if (xmms2ctrl_get_error() != ERROR_CONNECTION && !xmmsv_is_error(val)) {
+		xmmsv_get_int(val, &ptime);
 	}
 	if (cnt > 10 && GTK_IS_RANGE(scale)) {
 		cnt = 0;
@@ -477,16 +472,15 @@ static void sig_handle_playtime(xmmsc_result_t *res, void *userdata)
 				gtk_range_set_value(GTK_RANGE(scale), ptime);
 	}
 	cnt++;
+	return TRUE;
 }
 
-static void bc_handle_playback_status_change(xmmsc_result_t *res, void *userdata)
+static int bc_handle_playback_status_change(xmmsv_t *val, void *userdata)
 {
-	guint pb_status = 0;
+	gint pb_status = 0;
 
-	if (xmmsc_result_iserror(res))
-		return;
-	if (!xmmsc_result_get_uint(res, &pb_status))
-		return;
+	if (xmmsv_is_error(val) || !xmmsv_get_int(val, &pb_status))
+		return TRUE;
 
 	switch (pb_status) {
 		case XMMS_PLAYBACK_STATUS_PAUSE:
@@ -500,13 +494,14 @@ static void bc_handle_playback_status_change(xmmsc_result_t *res, void *userdata
 		default:
 			status_display_set_status(&sd, STATUS_PLAY);
 	}
+	return TRUE;
 }
 
-static void n_handle_playback_status_change(xmmsc_result_t *res, void *userdata)
+static int n_handle_playback_status_change(xmmsv_t *val, void *userdata)
 {
-	guint pb_status = 0;
+	gint pb_status = 0;
 
-	if (!xmmsc_result_iserror(res) && xmmsc_result_get_uint(res, &pb_status)) {
+	if (!xmmsv_is_error(val) && xmmsv_get_int(val, &pb_status)) {
 		switch (pb_status) {
 			case XMMS_PLAYBACK_STATUS_PAUSE:
 				status_display_set_status(&sd, STATUS_PAUSE);
@@ -519,8 +514,8 @@ static void n_handle_playback_status_change(xmmsc_result_t *res, void *userdata)
 				status_display_set_status(&sd, STATUS_PLAY);
 		}
 	}
-	
-	xmmsc_result_unref(res);
+
+	return FALSE;
 }
 
 static gboolean cb_timer_connection_lost(gpointer userdata)
@@ -623,11 +618,12 @@ static void cb_toggle_time(GtkWidget *widget, gpointer data)
 	flag_time_remaining = !flag_time_remaining;
 }
 
-static void n_quit_gtk_main(xmmsc_result_t *res, void *userdata)
+static int n_quit_gtk_main(xmmsv_t *val, void *userdata)
 {
 	if (xmms2ctrl_get_error() == ERROR_NONE)
 		xmmsc_disconnect_callback_set(connection, NULL, NULL);
 	gtk_main_quit();
+	return FALSE;
 }
 
 static void cb_quit_function(GtkWidget *widget, gpointer data)
